unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, JvStatusBar, StdCtrls, JvGroupBox, ExtCtrls,
  Buttons,
  IniFiles,
  Menus,
  JclSysInfo,
  JvPluginManager,
  JvExStdCtrls,
  JvExExtCtrls, JvExButtons,
  JvExComCtrls,
  JvBitBtn,
  JvComponent;

type
  TsCCCMain = class(TForm)
    StatusBar: TJvStatusBar;
    JvGroupBox1: TJvGroupBox;
    JvGroupBox2: TJvGroupBox;
    DisconnectBtn: TJvBitBtn;
    ConnectBtn: TJvBitBtn;
    ShutdownBtn: TJvBitBtn;
    StartUpBtn: TJvBitBtn;
    MainMenu: TMainMenu;
    Plugins1: TMenuItem;
    Configure1: TMenuItem;
    Unload2: TMenuItem;
    Load2: TMenuItem;
    List1: TMenuItem;
    PluginManager: TJvPluginManager;
    Splitter1: TSplitter;
    ServerLog: TMemo;
    DeviceLog: TMemo;
    Splitter2: TSplitter;
    procedure FormCreate(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure PluginManagerBeforeLoad(Sender: TObject; FileName: string;
      var AllowLoad: Boolean);
    procedure Unload1Click(Sender: TObject);
    procedure Load1Click(Sender: TObject);
    procedure UnloadPlugins;
    procedure PluginManagerAfterLoad(Sender: TObject; FileName: string;
      const ALibHandle: Cardinal; var AllowLoad: Boolean);
    procedure PluginManagerNewCommand(Sender: TObject; ACaption, AHint,
      AData: string; AShortCut: TShortCut; ABitmap: TBitmap;
      AEvent: TNotifyEvent);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  sCCCMain: TsCCCMain;

implementation

{$R *.dfm}

var
  NTOS: Boolean;
  AppPath, AppName: string;

procedure TsCCCMain.FormCreate(Sender: TObject);
begin
  AppPath := ExtractFilePath(Application.ExeName);
  AppName := ExtractFileName(Application.Title);
  PluginManager.PluginFolder := AppPath;
  if GetWindowsVersion in [wvWin95, wvWin95OSR2, wvWin98, wvWin98SE, wvWinME] then
    NTOS := False else NTOS := True;
end;

procedure TsCCCMain.FormActivate(Sender: TObject);
begin
  ServerLog.Clear;
  DeviceLog.Clear;
  PluginManager.LoadPlugins;
end;

procedure TsCCCMain.PluginManagerBeforeLoad(Sender: TObject;
  FileName: string; var AllowLoad: Boolean);
begin
  StatusBar.Panels[1].Text := 'Loading... ' + FileName;
end;

procedure TsCCCMain.Load1Click(Sender: TObject);
var
  i: integer;
begin
  if PluginManager.PluginCount > 0 then UnloadPlugins;
  PluginManager.LoadPlugins;
end;


procedure TsCCCMain.Unload1Click(Sender: TObject);
begin
  UnloadPlugins;
end;


procedure TsCCCMain.UnloadPlugins;
var
  i: integer;
begin
  if PluginManager.PluginCount > 0 then
  begin

    while MainMenu.Items[0].Count > 1 do
      MainMenu.Items[0].Delete(MainMenu.Items[0].Count - 1);

    for i := PluginManager.PluginCount - 1 downto 0 do
    begin
      StatusBar.Panels[1].Text := 'Unloading... ' +
        PluginManager.Plugins[PluginManager.PluginCount - 1].Description;
      PluginManager.UnloadPlugin(i);
    end;
    StatusBar.Panels[1].Text := '';
  end;
end;

procedure TsCCCMain.PluginManagerAfterLoad(Sender: TObject;
  FileName: string; const ALibHandle: Cardinal; var AllowLoad: Boolean);
begin
  StatusBar.Panels[1].Text := '';
end;


procedure TsCCCMain.PluginManagerNewCommand(Sender: TObject; ACaption,
  AHint, AData: string; AShortCut: TShortCut; ABitmap: TBitmap;
  AEvent: TNotifyEvent);
var
  Item: TMenuItem;
begin
  Item := NewItem(ACaption, scNone, False, True, AEvent, 0, '');
  MainMenu.Items[0].Add(Item);
end;


end.

